package com.evobms.project.VehicleData.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.evobms.framework.aspectj.lang.annotation.Log;
import com.evobms.framework.aspectj.lang.enums.BusinessType;
import com.evobms.project.VehicleData.domain.VehicleLocation;
import com.evobms.project.VehicleData.service.IVehicleLocationService;
import com.evobms.framework.web.controller.BaseController;
import com.evobms.framework.web.domain.AjaxResult;
import com.evobms.common.utils.poi.ExcelUtil;
import com.evobms.framework.web.page.TableDataInfo;

/**
 * 车辆位置数据Controller
 * 
 * @author ruoyi
 * @date 2025-11-15
 */
@RestController
@RequestMapping("/location/location")
public class VehicleLocationController extends BaseController
{
    @Autowired
    private IVehicleLocationService vehicleLocationService;

    /**
     * 查询车辆位置数据列表
     */
    @PreAuthorize("@ss.hasPermi('location:location:list')")
    @GetMapping("/list")
    public TableDataInfo list(VehicleLocation vehicleLocation)
    {
        startPage();
        List<VehicleLocation> list = vehicleLocationService.selectVehicleLocationList(vehicleLocation);
        return getDataTable(list);
    }

    /**
     * 导出车辆位置数据列表
     */
    @PreAuthorize("@ss.hasPermi('location:location:export')")
    @Log(title = "车辆位置数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, VehicleLocation vehicleLocation)
    {
        List<VehicleLocation> list = vehicleLocationService.selectVehicleLocationList(vehicleLocation);
        ExcelUtil<VehicleLocation> util = new ExcelUtil<VehicleLocation>(VehicleLocation.class);
        util.exportExcel(response, list, "车辆位置数据数据");
    }

    /**
     * 获取车辆位置数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('location:location:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(vehicleLocationService.selectVehicleLocationById(id));
    }

    /**
     * 新增车辆位置数据
     */
    @PreAuthorize("@ss.hasPermi('location:location:add')")
    @Log(title = "车辆位置数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody VehicleLocation vehicleLocation)
    {
        return toAjax(vehicleLocationService.insertVehicleLocation(vehicleLocation));
    }

    /**
     * 修改车辆位置数据
     */
    @PreAuthorize("@ss.hasPermi('location:location:edit')")
    @Log(title = "车辆位置数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody VehicleLocation vehicleLocation)
    {
        return toAjax(vehicleLocationService.updateVehicleLocation(vehicleLocation));
    }

    /**
     * 删除车辆位置数据
     */
    @PreAuthorize("@ss.hasPermi('location:location:remove')")
    @Log(title = "车辆位置数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(vehicleLocationService.deleteVehicleLocationByIds(ids));
    }
}
